@@ -5,13 +5,12 @@
 #define QT_PRODUCT_LICENSE  "qt-free"
 
 /* Build key */
-#define QT_BUILD_KEY "i686 Linux g++-3.* full-config"
+#define QT_BUILD_KEY "i686 Linux g++-4 full-config"
 
 /* Machine byte-order */
 #define Q_BIG_ENDIAN 4321
 #define Q_LITTLE_ENDIAN 1234
 #define Q_BYTE_ORDER Q_LITTLE_ENDIAN
-
 /* Compile time features */
 #define QT_LARGEFILE_SUPPORT 64
 #define QT_POINTER_SIZE 4
